<?php
/**
 * @brief		File Storage Extension: Images
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	(BIM) Topic Thumbnail
 * @since		18 Jan 2019
 */

namespace IPS\tthumb\extensions\core\FileStorage;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * File Storage Extension: Images
 */
class _Images
{
	/**
	 * Count stored files
	 *
	 * @return	int
	 */
	public function count()
	{
		return \IPS\Db::i()->select( 'COUNT(*)', 'tthumb_images' )->first();
	}
	
	/**
	 * Move stored files
	 *
	 * @param	int			$offset					This will be sent starting with 0, increasing to get all files stored by this extension
	 * @param	int			$storageConfiguration	New storage configuration ID
	 * @param	int|NULL	$oldConfiguration		Old storage configuration ID
	 * @throws	\UnderflowException					When file record doesn't exist. Indicating there are no more files to move
	 * @return	void|int							An offset integer to use on the next cycle, or nothing
	 */
	public function move( $offset, $storageConfiguration, $oldConfiguration=NULL )
	{
		$data		= \IPS\Db::i()->select( '*', 'tthumb_images', NULL, 'img_id', array( $offset, 1 ) )->first();
		$updates	= array();

		try
		{
			$image = \IPS\File::get( $oldConfiguration ?: 'tthumb_Images', $data['img_image'] )->move( $storageConfiguration );

			if ( (string) $image != $data['img_image'] )
			{
				$updates['img_image'] = (string) $image;
			}
			
			$image = \IPS\File::get( $oldConfiguration ?: 'tthumb_Images', $data['img_thumb'] )->move( $storageConfiguration );
			
			if ( (string) $image != $data['img_thumb'] )
			{
				$updates['img_thumb'] = (string) $image;
			}
		}
		catch( \Exception $e ){}

		if( $updates && \count( $updates ) )
		{
			\IPS\Db::i()->update( 'tthumb_images', $updates, array( 'img_id=?', $data['img_id'] ) );
		}		
	}

	/**
	 * Check if a file is valid
	 *
	 * @param	string	$file		The file path to check
	 * @return	bool
	 */
	public function isValidFile( $file )
	{
		try
		{
			$image	= \IPS\Db::i()->select( '*', 'tthumb_images', array( 'img_image=? OR img_thumb=?', (string) $file, (string) $file ) )->first();

			return TRUE;
		}
		catch ( \UnderflowException $e )
		{
			return FALSE;
		}			
	}

	/**
	 * Fix urls
	 *
	 * @return	bool
	 */	
	public function fixUrls( $offset )
	{
		$data = \IPS\Db::i()->select( '*', 'tthumb_images', NULL, 'img_id', array( $offset, 1 ) )->first();
		
		if ( $new = \IPS\File::repairUrl( $data['img_image'] ) )
		{
			\IPS\Db::i()->update( 'tthumb_images', array( 'img_image' => $new ), array( 'img_id=?', $data['img_id'] ) );
		}
		
		if ( $data['img_thumb'] && $new = \IPS\File::repairUrl( $data['img_thumb'] ) )
		{
			\IPS\Db::i()->update( 'tthumb_images', array( 'img_thumb' => $new ), array( 'img_id=?', $data['img_id'] ) );
		}				
	}		

	/**
	 * Delete all stored files
	 *
	 * @return	void
	 */
	public function delete()
	{
		foreach( \IPS\Db::i()->select( '*', 'tthumb_images' ) as $row )
		{
			try
			{
				\IPS\File::get( 'tthumb_Images', $row['img_image'] )->delete();
				\IPS\File::get( 'tthumb_Images', $row['img_thumb'] )->delete();
			}
			catch( \Exception $e ){}
		}			
	}
}